## normalize_tidy_pupil_data

normalize_tidy_pupil_data.py is a python script designed to compute pupil data normalizations and organization into pandas dataframe.

## Usage

Dependencies:
- Python 3.7.7
- NumPy 1.18.1
- SciPy 1.5.2
- Pandas 1.1.3

Speech in noise task:
- Disyllabic words are presented in quiet and noisy situations with and without hearing aids and participants have to repeat the word heard.
- Conditions: 'QuietUnaided', 'QuietAided', 'NoiseUnaided', 'NoiseAided'

Design of each trial:
- First second: stationary noise
- Auditory cue announcing the occurence of the next word ("Beep")
- 1.5 s of stationary noise preceding the word
- 4 s (including the word) to process the word
- Auditory cue ("Blop") announcing the start of the temporal window for repeating the word
- 5 s temporal window to allow participant to repeat the word just heard
![Alt Text](img/trial_bsl.png)

Data files:
- 8 block files per subject (2 blocks per condition):
  - subj*01__*.csv
  .
  .
  .
  - subj*08__*.csv

- 4 files per block:
  - subj*01__*details.csv: block details (with conditions: 'SS'='QuietUnaided', 'AS'='QuietAided', 'SN'='NoiseUnaided', 'AN'='NoiseAided')
  - subj*01__*lim.csv: trial boundaries
  - subj*01__*samps9liss.csv: pupil diameters
  - subj*01__*SMIBman.csv: manually included trials infos

Normalization methods:
- raw: preprocessed data only
- bsl_corr_only: baseline corrected data (see Zekveld et al. 2010)
- prop_change: diameters expressed as proportional change from baseline (see Wierda et al. 2012)
- wtms: data normalized using Within-trial mean scaling (see Kuchinsky et al. 2013)
- gms: data normalized using Grand mean scaling (see Engelhardt et al. 2010)
- zscore: pupil diameters expressed as Z-score (see McCloy et al. 2016)

Baseline periods (see trial figure):
- baselineA (Start) onset: Start (start of trial)
- baselineB (StartCue) onset: Beep (first auditory cue)
- baselineC (EndCue) onset: end of Beep (end of first auditory cue)
- baselineD (StartWord) offset: Beginning of word

Baseline durations:
- 500 ms
- 1000 ms

Trials infos and pupil diameters are collected from data files (described in Data files). Pupil data are then normalized using 5 normalization methods (described in Normalization methods), 4 baseline periods (described in Baseline periods) and 2 baseline durations (described in Baseline durations).
Directly run code file with text editor or python scientific environment. 
normalize_tidy_pupil_data.py returns 1 pandas DataFrame per subject with normalized pupil diameters.

## License

[GPL v3] (https://www.gnu.org/licenses/gpl-3.0.en.html)
